#
# spec file for package lldpd
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lldpd_user lldpd
%define lldpd_group lldpd
%define lldpd_chroot %{_localstatedir}/run/lldpd
%define sover 4
%define libname liblldpctl%{sover}
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           lldpd
Version:        1.0.19
Release:        1.3
Summary:        Implementation of IEEE 802.1ab (LLDP)
# We have some GPL linux headers in include/linux, they are used on
# platforms where glibc headers are not recent enough
License:        GPL-2.0-or-later AND ISC
Group:          System/Daemons
URL:            https://vincentbernat.github.io/
Source0:        https://media.luffy.cx/files/lldpd/%{name}-%{version}.tar.gz
Source1:        lldpd.sysconfig
Source2:        https://media.luffy.cx/files/lldpd/%{name}-%{version}.tar.gz.gpg#/%{name}-%{version}.tar.gz.asc
Source3:        http://keyserver.ubuntu.com:11371/pks/lookup?op=get&search=0x95A42FE8353525F9#/%{name}.keyring
Patch0:         harden_lldpd.service.patch
BuildRequires:  net-snmp-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libbsd)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libxml-2.0)
Requires(pre):  %fillup_prereq
Requires(pre):  pwdutils

%description
This implementation provides LLDP sending and reception, supports VLAN
and includes an SNMP subagent that can interface to an SNMP agent
through AgentX protocol.

LLDP is an industry standard protocol designed to supplant proprietary
Link-Layer protocols such as Extreme EDP (Extreme Discovery Protocol)
and CDP (Cisco Discovery Protocol). The goal of LLDP is to provide an
inter-vendor compatible mechanism to deliver Link-Layer notifications
to adjacent network devices.

This daemon is also able to deal with CDP, FDP, SONMP and EDP
protocol. It also handles LLDP-MED extension.

%package -n %{libname}
Summary:        Implementation of IEEE 802.1ab
License:        MIT
Group:          System/Libraries

%description -n %{libname}
This package provides the shared library for lldpd.

LLDP is an industry standard protocol designed to supplant proprietary
Link-Layer protocols such as Extreme EDP (Extreme Discovery Protocol)
and CDP (Cisco Discovery Protocol). The goal of LLDP is to provide an
inter-vendor compatible mechanism to deliver Link-Layer notifications
to adjacent network devices.

%package devel
Summary:        Headers for the lldpd implementation
License:        MIT
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}-%{release}

%description devel
This package is required to develop alternate clients for lldpd.

LLDP is an industry standard protocol designed to supplant proprietary
Link-Layer protocols such as Extreme EDP (Extreme Discovery Protocol)
and CDP (Cisco Discovery Protocol). The goal of LLDP is to provide an
inter-vendor compatible mechanism to deliver Link-Layer notifications
to adjacent network devices.

%prep
%autosetup -p1

%build
%configure \
   --with-snmp \
   --with-xml \
   --with-libbsd \
   --enable-cdp \
   --enable-edp \
   --enable-sonmp \
   --enable-fdp \
   --enable-lldpmed \
   --enable-dot1 \
   --enable-dot3 \
   --enable-custom \
   --disable-oldies \
   --with-privsep-user=%{lldpd_user} \
   --with-privsep-group=%{lldpd_group} \
   --with-privsep-chroot=%{lldpd_chroot} \
   --with-systemdsystemunitdir=%{_unitdir} \
   --with-sysusersdir=no \
   --docdir=%{_docdir}/lldpd \
   --enable-pie \
   --disable-static

[ -f %{_includedir}/net-snmp/agent/struct.h ] || touch src/struct.h
%make_build

%install
%make_install
install -Dpm 0644 %{SOURCE1} %{buildroot}%{_fillupdir}/sysconfig.lldpd
install -dm0755 %{buildroot}/%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rclldpd
rm -f %{buildroot}%{_libdir}/liblldpctl.la

%pre
# Create lldpd user/group
getent group %{lldpd_group} >/dev/null || \
 %{_sbindir}/groupadd -r %{lldpd_group}
getent passwd %{lldpd_user} >/dev/null || \
 %{_sbindir}/useradd -g %{lldpd_group} -M -r -s /sbin/nologin \
 -c "LLDP daemon" -d %{lldpd_chroot} %{lldpd_user}

%service_add_pre lldpd.service

%post -n %{libname} -p /sbin/ldconfig
%postun  -n %{libname} -p /sbin/ldconfig

%post
%service_add_post lldpd.service
%fillup_only

%preun
%service_del_preun lldpd.service

%postun
%service_del_postun lldpd.service

%files
%dir %{_docdir}/lldpd
%doc %{_docdir}/lldpd/NEWS
%license %{_docdir}/lldpd/LICENSE
%doc %{_docdir}/lldpd/ChangeLog
%doc %{_docdir}/lldpd/README.md
%doc %{_docdir}/lldpd/CONTRIBUTE.md
%{_sbindir}/lldpd
%{_sbindir}/lldpctl
%{_sbindir}/lldpcli
%{_datadir}/zsh
%{_datadir}/bash-completion
%{_mandir}/man8/lldp*.8%{?ext_man}
%config %{_sysconfdir}/lldpd.d
%{_unitdir}/lldpd.service
%{_sbindir}/rclldpd
%{_fillupdir}/sysconfig.lldpd

%files -n %{libname}
%{_libdir}/liblldpctl.so.*

%files devel
%{_libdir}/liblldpctl.so
%{_libdir}/pkgconfig/lldpctl.pc
%{_includedir}/lldpctl.h
%{_includedir}/lldp-const.h

%changelog
* Mon Jan 13 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.19
  Changes:
  * Add cvlan/svlan/tpmr capabilities.
  * Add lldpctl_watch_sync_unblock to liblldpctl.
  * Add C++ wrapper for lldpctl.
  Fix:
  * Fix AppArmor policy for /run/lldpd/lldpd.socket.lock.
  * Do not query stats for a down interface on Linux.
* Sun Jan 28 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.18
  Changes:
  * Remove support for building 802.3bt TLVs (broken).
  Fixes:
  * Fix memory leaks in EDP/FDP decoding when receiving some TLVs
    twice.
  * Do not set interface description continuously.
  * Use a different Netlink socket for changes and queries.
* Mon May 29 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.17:
  * Fix: Read overflow when parsing CDP addresses.
  * Don't output empty lines on configure commands.
* Fri Nov 11 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.16
  * Do not use 00:00:00:00:00:00 as chassis ID.
  * Do not busy loop when an interface with a neighbor disappears.
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.15
  * protocol/lldp: accept unknown TLVs on known orgs
  * client: Added support to override system capabilities
  * netlink: ignore IPv6 temporary addresses
* Sat May 21 2022 Martin Hauke <mardnh@gmx.de>
- Upate to version 1.0.14
  Changes:
  * Add configure commands to alter inventory TLVs.
  Fixes:
  * Update seccomp rules for newer kernel/libc.
  * Correctly handle an interface whose index has changed.
  * Don't send VLANs when there are too many.
* Sun Nov 14 2021 Martin Hauke <mardnh@gmx.de>
- Update to versino 1.0.13
  * Add support for 2.5G, 5G, 25G and 50G based Ethernet.
  * Fix LLDP packets encapsuled in VLAN 0 in some conditions.
  * Fix heap overflow when reading SONMP. CVE-2021-43612.
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Tue Oct  5 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_lldpd.service.patch
* Fri Aug 20 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.12:
  Fix:
  * Use a dedicated file lock to prevent concurrent changes from
    lldpcli.
  * Require/display powerpairs for Dot3 power even when device
    type is PD.
- Fix URL
* Sun May  2 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.11:
  * Changes:
    + Disable LLDP in firmware for Intel X7xx cards.
  * Fix:
    + Ensure Intel E8xx cards can transmit LLDP packets.
* Sat Apr 10 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.10:
  Fix:
  * Fix chroot directory creation.
* Fri Apr  2 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.9:
  Fix:
  * Do not use interface alias if we set it ourselves.
  * More memory leak fixes on duplicate TLVs in LLDP, CDP and EDP
    (related to CVE-2020-27827).
  Changes:
  * Display port status with "show interfaces".
  * Do not display "age" and "via" when using "show interfaces".
* Thu Jan 14 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.8:
  Fix:
  * Out-of-bound read access when parsing LLDP-MED civic address in
    liblldpctl for malformed fields.
  * Fix memory leak when receiving LLDPU with duplicate fields.
    CVE-2020-27827.
  Changes:
  * Enable "router" capability bit when IPv6 routing is enabled.
* Sun Nov  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.7:
  Fix:
  * Do not listen only to LLDP packets on Linux. When an interface
    is enslaved to an Open vSwitch, incoming packets are missed.
* Tue Oct 13 2020 Jan Engelhardt <jengelh@inai.de>
- Replace old specfile constructs. Do not suppress errors from
  useradd. Require right subpackage from lldpd-devel. Trim
  redundancies from descriptions.
* Sat Sep  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.6:
  Fix:
  * Do not loose chassis local information when interface status
    changes.
  * Fix SNMP walk on lldpRemTable when missing remote system
    name or description.
  * Remove length limitation on system description and platform.
  Changes:
  * Deprecate use of lldpctl_watch_callback(). Use
    lldpctl_watch_callback2() instead.
  * Upgrade embedded libevent to 2.1.11-stable
  * Add support of sending LLDP frames on a configured VLAN
* Sun Feb  2 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.5:
  Changes:
  * Interface names are also matched for management addresses.
  * On Linux, only register protocol handler for LLDP when only LLDP
    is enabled.
  * Stricter on LLDP incoming frames validation.
  * Add support for VLAN-aware bridges for Linux (no range support).
  * Add support for 802.3BT (no SNMP support).
  * Add support for millisecond-grained tx-interval
  * Use generic names for VLAN names, instead of interface names (eg
    vlan100 instead of eth1.100).
  Fix:
  * Don't clear chassis TLV on shutdown LLDPDU.
  * Don't require/display powerpairs for Dot3 power when device type
    is PD.
* Wed Nov 13 2019 Martin Hauke <mardnh@gmx.de>
- Correct License
  * MIT -> ISC
* Sun Jun 16 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.4:
  Changes:
  * Add "configure system max-neighbors XX" command to modify maximum
    of neighbors accepted per port.
  * Implement lldpRemOrgDefInfoTable table for custom TLVs.
  * Fix:
  * Better compliance for statsTLVsUnrecognizedTotal and
    statsAgeoutsTotal counters.
  * On Linux, handle rare blocking case in Netlink code.
* Thu Feb 14 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.0.3:
  * Fix creation of chroot directory.
- Simplify spec file
* Mon Dec  3 2018 mardnh@gmx.de
- Update to version 1.0.2
  * On Linux, the monitor process will now drop its privileges
    instead of running as root. It will keep CAP_NET_RAW,
    CAP_NET_ADMIN and CAP_DAC_OVERRIDE capabilities.
  * Support for CDP PD PoE (with negotiation).
  * Move support for bonded devices on Linux < 2.6.27 into the
    `--enable-oldies` option. This avoids duplicate packets
    starting from Linux 4.19.
* Wed Aug  1 2018 mpluskal@suse.com
- Adjust sysconfig
* Mon Apr  9 2018 mardnh@gmx.de
- Update to version 1.0.1 (boo#1103351)
  * Use "mkdir -p" instead of "mkdir" in systemd unit.
* Mon Apr  9 2018 mardnh@gmx.de
- Update to version 1.0.0
  * Changes:
    + Chassis ID can be set to an arbitrary value with "configure
    system chassisid".
    + Port description can be overriden directly with "configure
    lldp portdescription".
    + Command "configure system interface permanent" enables one to
    specify a pattern for interfaces to be kept in memory even when
    they are removed from the system.
  * Fix:
    + Ensure chassis-related changes are propagated immediately.
    + Ensure management address change is correctly detected.
* Mon Dec 18 2017 mpluskal@suse.com
- Disable seccomp as it breaks on Factory
- Further update sysconfig
- Some more spec-cleaner goodness
* Sat Dec 16 2017 astieger@suse.com
- verify source signature
* Mon Dec 11 2017 mpluskal@suse.com
- Enable seccomp for Factory
- Adjust default sysconfig to enable other protocols and self
  advertisment
- Do not create user/grou starting with underscore (_lldpd)
* Mon Dec  4 2017 mpluskal@suse.com
- Use fillupdir macro
- Enable libbsd
- Fix group for devel subpackage
* Mon Nov 27 2017 mpluskal@suse.com
- Clarify licensing and usage of some header files
- Enable support for libseccomp (disabled by default)
- Make buildign more verbose
* Wed Nov 22 2017 mardnh@gmx.de
- Created lldpd.changes file (converted inline Changelog via
  spec2changelog)
- Specfile cleanup (removed all stuff that is not relevant for
  recent (open)SUSE versions.)
* Tue Nov 21 2017 bernat@luffy.cx
- New upstream version.
* Sun Aug 20 2017 bernat@luffy.cx
- New upstream version.
* Sun Mar 19 2017 bernat@luffy.cx
- New upstream version.
* Sat Jan 21 2017 bernat@luffy.cx
- New upstream version.
* Fri Sep 30 2016 bernat@luffy.cx
- New upstream version.
* Fri Jun 17 2016 bernat@luffy.cx
- New upstream version.
* Sat May 21 2016 bernat@luffy.cx
- New upstream version.
* Sat Mar 19 2016 bernat@luffy.cx
- New upstream version.
* Sat Feb 20 2016 bernat@luffy.cx
- New upstream version.
* Fri Jan  1 2016 bernat@luffy.cx
- New upstream version.
- Do not rely on libnl3.
* Sun Dec 27 2015 bernat@luffy.cx
- New upstream version.
- Use system libnl3 when possible.
- Use system libevent when possible.
* Wed Sep  9 2015 bernat@luffy.cx
- New upstream version.
* Fri Aug  7 2015 bernat@luffy.cx
- New upstream version.
* Wed May 20 2015 bernat@luffy.cx
- New upstream version.
* Sat Apr  4 2015 bernat@luffy.cx
- New upstream version.
* Tue Dec 30 2014 bernat@luffy.cx
- New upstream version.
* Sat Nov 22 2014 bernat@luffy.cx
- New upstream version.
- Completion for bash and zsh.
* Wed Oct  8 2014 bernat@luffy.cx
- New upstream version.
- Completion for bash and zsh.
* Mon Jul 21 2014 bernat@luffy.cx
- New upstream version.
* Wed May 28 2014 bernat@luffy.cx
- New upstream version.
* Sun Apr 13 2014 bernat@luffy.cx
- New upstream version.
* Sun Nov 10 2013 bernat@luffy.cx
- New upstream version.
* Fri Jul 12 2013 bernat@luffy.cx
- New upstream version.
* Sat Jun 22 2013 bernat@luffy.cx
- New upstream version.
* Sun May 12 2013 bernat@luffy.cx
- New upstream version.
* Fri Apr 19 2013 bernat@luffy.cx
- New upstream version.
* Sat Jan 12 2013 bernat@luffy.cx
- New upstream version.
* Sun Jan  6 2013 bernat@luffy.cx
- New upstream version.
- Requires readline-devel.
- Ships lldpcli.
* Thu Sep 27 2012 bernat@luffy.cx
- New upstream version
- Do not require libevent, use embedded copy.
- Provide a -devel package.
* Fri Jun 11 2010 bernat@luffy.cx
- New upstream version
- Define bcond_without and with macros if not defined to be compatible
  with RHEL
- Requires useradd and groupadd
- Adapt to make it work with SuSE
- Provide an init script targetted at SuSE
- Build require lm_sensors-devel on RHEL
* Fri Mar 12 2010 bernat@luffy.cx
- New upstream version
- Add XML support
* Tue May 19 2009 bernat@luffy.cx
- Add variables
- Enable SNMP support
- Add _lldpd user creation
- Add initscript
- New upstream version
* Mon May 18 2009 dean.hamstead@optusnet.com.au
- Initial attempt
